/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: TaxonomyPickerController.java,v 206d261ec46b 2010/08/25 22:08:44 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.taxonomy;

import javax.annotation.Nonnull;
import java.util.ArrayList;
import java.util.List;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.bluebill.observation.Observation;
import it.tidalwave.bluebill.observation.ObservationManager;
import it.tidalwave.bluebill.observation.ObservationSet;
import it.tidalwave.bluebill.mobile.observation.ObservationClipboard;
import org.openide.util.NbBundle;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
public class TaxonomyPickerController
  {
    @Nonnull
    protected final TaxonomyPickerUI ui;

    @Nonnull
    private final ObservationManager observationManager = Locator.find(ObservationManager.class);

    @Nonnull
    private final ObservationClipboard observationClipboard = Locator.find(ObservationClipboard.class);

    protected final List<TaxonomyDescription> taxonomies = new ArrayList<TaxonomyDescription>();

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public TaxonomyPickerController (final @Nonnull TaxonomyPickerUI ui)
      {
        this.ui = ui;
        taxonomies.add(new TaxonomyDescription("AOU7th", 
                                               "The American Ornithologists' Union 7th Edition",
                                               "North America"));
        taxonomies.add(new TaxonomyDescription("EBNItalia2003", 
                                               "EBN Italia 2003",
                                               "Western Palearctic Ecozone (Europe, Western Asia, North Africa)"));
        taxonomies.add(new TaxonomyDescription("RobertsVII", 
                                               "Roberts VII Edition",
                                               "Southern Africa"));
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public void check()
      {
        final ObservationSet observationSet = observationManager.findOrCreateObservationSetById(null);
        final boolean observationsInserted = observationSet.find(Observation.class).count() > 0;
        final boolean insertInProgress = observationClipboard.getBuilder().getItemCount() > 0;

        if (observationsInserted || insertInProgress)
          {
            final String title   = NbBundle.getMessage(TaxonomyPickerController.class, "cantChangeChecklist_title");
            final String message = NbBundle.getMessage(TaxonomyPickerController.class, "cantChangeChecklist_message");
            ui.getCommonUITasks().alertDialog2(title, message, new Runnable()
              {
                public void run()
                  {
                    ui.finish();
                  }
              });
          }
      }
  }
